@@ -27,6 +27,8 @@
 #'     to disable confidence intervals.}
 #'   \item{midpoint}{if `FALSE` do not show guidelines associated with the
 #'     curve mid-point.}
+#'   \item{plot_data}{if `FALSE` do not show data points used for fitting in the
+#'     plot.}
 #'   \item{legend_show}{if `FALSE` do not show the legend.}
 #'   \item{legend_location}{character string with custom legend position. See
 #'     \code{link[graphics]{legend}} for possible keywords.}
@@ -89,6 +91,11 @@ plot.drda <- function(x, ...) {
     midpoint <- TRUE
   }
 
+  plot_data <- dotargs[["plot_data"]]
+  if (is.null(plot_data)) {
+    plot_data <- TRUE
+  }
+
   params <- plot_params(
     x, dotargs[["base"]], dotargs[["xlim"]], dotargs[["ylim"]]
   )
@@ -139,7 +146,9 @@ plot.drda <- function(x, ...) {
     polygon(xci, yci, col = adjustcolor(col, 0.08), border = FALSE)
   }
 
-  points(params$xv, params$yv, col = col)
+  if (plot_data) {
+    points(params$xv, params$yv, col = col)
+  }
   lines(params$xx, params$mu, lty = 2, lwd = 2, col = col)
 
   if (midpoint && !is.null(params$midpoint_x)) {
@@ -233,6 +242,11 @@ plot.drdalist <- function(x, ...) {
     midpoint <- TRUE
   }
 
+  plot_data <- dotargs[["plot_data"]]
+  if (is.null(plot_data)) {
+    plot_data <- TRUE
+  }
+
   params <- vector("list", n_curves)
 
   plot_type <- 1
@@ -259,8 +273,9 @@ plot.drdalist <- function(x, ...) {
 
   tmp <- vapply(params, function(w) w$xlim, numeric(2))
 
-  j <- which.max(tmp[2, ])
-  xlim <- c(min(tmp[1, ]), tmp[2, j])
+  j1 <- which.min(tmp[1, ])
+  j2 <- which.max(tmp[2, ])
+  xlim <- c(tmp[1, j1], tmp[2, j2])
 
   tmp <- vapply(params, function(w) w$ylim, numeric(2))
   ylim <- c(min(tmp[1, ]), max(tmp[2, ]))
@@ -273,32 +288,56 @@ plot.drdalist <- function(x, ...) {
   )
 
   if (plot_type == 1) {
-    axis(1, at = params[[j]]$x_axis_ticks, labels = params[[j]]$x_axis_labels)
+    axis(1, at = params[[j2]]$x_axis_ticks, labels = params[[j2]]$x_axis_labels)
   } else if (plot_type == 2) {
+    # on the left side of the plot we must use the smallest values
     axis(
-      1, at = params[[j]]$x_axis_ticks_1, labels = params[[j]]$x_axis_labels_1
-    )
-    axis(
-      1, at = params[[j]]$x_axis_ticks_2, labels = params[[j]]$x_axis_labels_2
+      1, at = params[[j1]]$x_axis_ticks_1, labels = params[[j1]]$x_axis_labels_1
     )
 
+    # default ticks are those of "j1"
+    tks_1 <- params[[j1]]$x_axis_ticks_2
+    lbl_1 <- params[[j1]]$x_axis_labels_2
+
+    # does "j2" have extra ticks to add?
+    # remove the "gap" tick because we are using that of "j1"
+    tks_2 <- params[[j2]]$x_axis_ticks_2[-1]
+    lbl_2 <- params[[j2]]$x_axis_labels_2[-1]
+
+    idx <- !(tks_2 %in% tks_1)
+    if (any(idx)) {
+      tks_1 <- c(tks_1, tks_2[idx])
+      lbl_1 <- c(lbl_1, lbl_2[idx])
+
+      ord <- order(tks_1)
+      tks_1 <- tks_1[ord]
+      lbl_1 <- lbl_1[ord]
+    }
+
+    axis(1, at = tks_1, labels = lbl_1)
+
     axis(
-      1, at = params[[j]]$x_axis_ticks_1[2], labels = FALSE, tcl = -par("tcl")
+      1, at = params[[j1]]$x_axis_ticks_1[2], labels = FALSE, tcl = -par("tcl")
     )
     axis(
-      1, at = params[[j]]$x_axis_ticks_2[1], labels = FALSE, tcl = -par("tcl")
+      1, at = params[[j1]]$x_axis_ticks_2[1], labels = FALSE, tcl = -par("tcl")
     )
   }
 
-  axis(1, at = params[[j]]$x_axis_minor, labels = FALSE, tcl = par("tcl") * 0.5)
+  axis(
+    1,
+    at = sort(unique(c(params[[j1]]$x_axis_minor, params[[j2]]$x_axis_minor))),
+    labels = FALSE, tcl = par("tcl") * 0.5
+  )
+
   axis(2, at = pretty(ylim))
 
-  box_x <- par("usr")[params[[j]]$box$x]
-  box_y <- par("usr")[params[[j]]$box$y]
+  box_x <- par("usr")[params[[j1]]$box$x]
+  box_y <- par("usr")[params[[j1]]$box$y]
 
-  if (!is.null(params[[j]]$box$z)) {
-    box_x[1] <- params[[j]]$box$z[1]
-    box_x[10] <- params[[j]]$box$z[2]
+  if (!is.null(params[[j1]]$box$z)) {
+    box_x[1] <- params[[j1]]$box$z[1]
+    box_x[10] <- params[[j1]]$box$z[2]
   }
 
   lines(x = box_x, y = box_y)
@@ -319,7 +358,9 @@ plot.drdalist <- function(x, ...) {
       polygon(xci, yci, col = adjustcolor(col[i], 0.08), border = FALSE)
     }
 
-    points(params[[i]]$xv, params[[i]]$yv, col = col[i])
+    if (plot_data) {
+      points(params[[i]]$xv, params[[i]]$yv, col = col[i])
+    }
     lines(params[[i]]$xx, params[[i]]$mu, lty = 2, lwd = 2, col = col[i])
 
     if (midpoint && !is.null(params[[i]]$midpoint_x)) {
@@ -379,7 +420,7 @@ plot_params.logistic <- function(x, base, xlim, ylim) {
       k <- log(2)
     } else if (base != "e" && base != "n") {
       # only "n", e", "2", and "10" are supported.
-      base <- "n"
+      stop("base value not supported", call. = FALSE)
     }
   } else {
     # by default we do not change the scale
@@ -434,6 +475,12 @@ plot_params.logistic <- function(x, base, xlim, ylim) {
     wv <- wv[idx]
   }
 
+  # make sure data is sorted according to `xv`
+  ord <- order(xv, yv, wv)
+  xv <- xv[ord]
+  yv <- yv[ord]
+  wv <- wv[ord]
+
   if (is.null(xlim)) {
     xlim <- extendrange(xv, f = 0.08)
 
@@ -597,7 +644,7 @@ plot_params.loglogistic <- function(x, base, xlim, ylim) {
       h <- exp(2)
     } else if (base != "e" && base != "n") {
       # only "n", e", "2", and "10" are supported.
-      base <- "n"
+      stop("base value not supported", call. = FALSE)
     }
   } else {
     # by default we do not change the scale
@@ -652,6 +699,12 @@ plot_params.loglogistic <- function(x, base, xlim, ylim) {
     wv <- wv[idx]
   }
 
+  # make sure data is sorted according to `xv`
+  ord <- order(xv, yv, wv)
+  xv <- xv[ord]
+  yv <- yv[ord]
+  wv <- wv[ord]
+
   len <- length(xv)
   zero_x <- xv == 0
 
@@ -783,7 +836,11 @@ plot_params.loglogistic <- function(x, base, xlim, ylim) {
 
     x_axis_ticks <- seq(x1, x2, by = ceiling((x2 - x1) / 6))
     x_axis_labels <- str2expression(
-      c("0", paste(base, "^", x_axis_ticks[-1], sep = ""))
+      if (any(zero_x)) {
+        c("0", paste(base, "^", x_axis_ticks[-1], sep = ""))
+      } else {
+        paste(base, "^", x_axis_ticks, sep = "")
+      }
     )
 
     # the following is based on https://stackoverflow.com/a/6956596/7073122
@@ -801,22 +858,25 @@ plot_params.loglogistic <- function(x, base, xlim, ylim) {
       x_axis_minor > xlim[1] & x_axis_minor < xlim[2]
     ]
 
-    x_axis_ticks[1] <- xv[1]
+    if (any(zero_x)) {
+      # when there is a zero dose we must show a gap in the x-axis
+      x_axis_ticks[1] <- xv[1]
 
-    p1 <- 0.25 * (x_axis_ticks[2] - x_axis_ticks[1])
-    p2 <- 0.35 * (x_axis_ticks[2] - x_axis_ticks[1])
+      p1 <- 0.25 * (x_axis_ticks[2] - x_axis_ticks[1])
+      p2 <- 0.35 * (x_axis_ticks[2] - x_axis_ticks[1])
 
-    x1 <- x_axis_ticks[1] + p1
-    x2 <- x_axis_ticks[1] + p2
+      x1 <- x_axis_ticks[1] + p1
+      x2 <- x_axis_ticks[1] + p2
 
-    x_axis_minor <- x_axis_minor[x_axis_minor >= x2]
+      x_axis_minor <- x_axis_minor[x_axis_minor >= x2]
 
-    x_axis_ticks_1 <- c(x_axis_ticks[1], x1)
-    x_axis_labels_1 <- c(x_axis_labels[1], "")
-    x_axis_ticks_2 <- c(x2, x_axis_ticks[-1])
-    x_axis_labels_2 <- c("", x_axis_labels[-1])
+      x_axis_ticks_1 <- c(x_axis_ticks[1], x1)
+      x_axis_labels_1 <- c(x_axis_labels[1], "")
+      x_axis_ticks_2 <- c(x2, x_axis_ticks[-1])
+      x_axis_labels_2 <- c("", x_axis_labels[-1])
 
-    box$z <- c(x1, x2)
+      box$z <- c(x1, x2)
+    }
   } else {
     mp <- exp(mp)
     f <- fn(x, mp, theta)
